@@ -394,7 +394,6 @@ static PyObject *Admin_create_topics (Handle *self, PyObject *args,
                         PyErr_Format(PyExc_ValueError,
                                      "Invalid NewTopic(%s): %s",
                                      newt->topic, errstr);
-                        i++;
                         goto err;
                 }
 
@@ -1541,7 +1540,7 @@ PyTypeObject AdminType = {
         "\n"
         ".. py:function:: Admin(**kwargs)\n"
         "\n"
-        "  Create new AdminClient instance using provided configuration dict.\n"
+        "  Create a new AdminClient instance using the provided configuration dict.\n"
         "\n"
         "This class should not be used directly, use confluent_kafka.AdminClient\n."
         "\n"
