@@ -486,21 +486,21 @@ static PyMethodDef Message_methods[] = {
 	},
 	{ "timestamp", (PyCFunction)Message_timestamp, METH_NOARGS,
           "Retrieve timestamp type and timestamp from message.\n"
-          "The timestamp type is one of:\n"
-          " * :py:const:`TIMESTAMP_NOT_AVAILABLE`"
-          " - Timestamps not supported by broker\n"
-          " * :py:const:`TIMESTAMP_CREATE_TIME` "
-          " - Message creation time (or source / producer time)\n"
-          " * :py:const:`TIMESTAMP_LOG_APPEND_TIME` "
-          " - Broker receive time\n"
+          "The timestamp type is one of:\n\n"
+          "  * :py:const:`TIMESTAMP_NOT_AVAILABLE` "
+          "- Timestamps not supported by broker.\n"
+          "  * :py:const:`TIMESTAMP_CREATE_TIME` "
+          "- Message creation time (or source / producer time).\n"
+          "  * :py:const:`TIMESTAMP_LOG_APPEND_TIME` "
+          "- Broker receive time.\n"
           "\n"
-          "The returned timestamp should be ignored if the timestamp type is "
+          "  The returned timestamp should be ignored if the timestamp type is "
           ":py:const:`TIMESTAMP_NOT_AVAILABLE`.\n"
           "\n"
           "  The timestamp is the number of milliseconds since the epoch (UTC).\n"
           "\n"
-          "  Timestamps require broker version 0.10.0.0 or later and \n"
-          "  ``{'api.version.request': True}`` configured on the client.\n"
+          "  Timestamps require broker version 0.10.0.0 or later and "
+          "``{'api.version.request': True}`` configured on the client.\n"
           "\n"
 	  "  :returns: tuple of message timestamp type, and timestamp.\n"
 	  "  :rtype: (int, int)\n"
@@ -2193,7 +2193,7 @@ static PyObject *libversion (PyObject *self, PyObject *args) {
  * MM=major, mm=minor, RR=revision, PP=patchlevel (not used)
  */
 static PyObject *version (PyObject *self, PyObject *args) {
-	return Py_BuildValue("si", "1.1.0", 0x01010000);
+	return Py_BuildValue("si", "1.3.0", 0x01030000);
 }
 
 static PyMethodDef cimpl_methods[] = {
